uniform sampler2D textureMap0;
uniform sampler2D textureMap1;
uniform sampler2D textureMap2;
uniform sampler2D textureMap3;

uniform highp vec4 uColor;
uniform highp int uDamageLevel;

varying highp vec2 vTexCoord;
varying highp vec3 vLightVec;
varying highp vec3 vHalfVec;

void main()
{
	highp vec4 base = texture2D(textureMap0, vTexCoord.xy);
	highp vec3 bump = texture2D(textureMap1, vTexCoord.xy).rgb * 2.0 - 1.0;
	highp float spec = texture2D(textureMap2, vTexCoord.xy).r;
	highp vec4 damage = texture2D(textureMap3, vTexCoord.xy);

	bump.g = -bump.g;

	highp float nDotL = max(dot(bump * 1.0, vLightVec), 0.0);

	highp float nDotH = max(dot(bump * 1.0, vHalfVec), 0.0);
	highp float specPower = pow(nDotH, 15.0);

	highp vec3 ambient = vec3(0.3, 0.3, 0.3) * base.rgb;

	if (uDamageLevel == 1)
		gl_FragColor.rgb = (ambient + base.rgb * nDotL + specPower * spec) * damage.a;
	else if (uDamageLevel == 2)
		gl_FragColor.rgb = (ambient + base.rgb * nDotL + specPower * spec) * damage.b;
	else if (uDamageLevel == 3)
		gl_FragColor.rgb = (ambient + base.rgb * nDotL + specPower * spec) * damage.g;
	else if (uDamageLevel == 4)
		gl_FragColor.rgb = (ambient + base.rgb * nDotL + specPower * spec) * damage.r;
	else
		gl_FragColor.rgb = (ambient + base.rgb * nDotL + specPower * spec);
	

	gl_FragColor.a = base.a;
	gl_FragColor *= uColor;
}
