uniform highp mat4 uModelViewMatrix;
uniform highp mat3 uNormalMatrix;
uniform highp mat4 uObjectMatrix;
uniform highp vec3 uLightPos;
uniform highp vec3 uViewPos;

attribute highp vec3 position;

attribute highp vec3 tangent;
attribute highp vec3 binormal;
attribute highp vec3 normal;

attribute highp vec2 texCoord;

varying highp vec2 vTexCoord;
varying highp vec3 vLightVec;
varying highp vec3 vHalfVec;

void main()
{
	gl_Position = uModelViewMatrix * vec4(position, 1.0);
	
	highp vec4 vertexPos = uObjectMatrix * vec4(position, 1);
	
	highp vec3 vecToLight = normalize(uLightPos.xyz);
	highp vec3 halfAngVec = normalize(normalize(uLightPos.xyz) + normalize(uViewPos - vertexPos.xyz));

	vLightVec.x = dot(uNormalMatrix * tangent, vecToLight);
	vLightVec.y = dot(uNormalMatrix * binormal, vecToLight);
	vLightVec.z = dot(uNormalMatrix * normal, vecToLight);
	
	vHalfVec.x = dot(uNormalMatrix * tangent, halfAngVec);
	vHalfVec.y = dot(uNormalMatrix * binormal, halfAngVec);
	vHalfVec.z = dot(uNormalMatrix * normal, halfAngVec);
	
	vTexCoord = texCoord;
}
